@@ -29,14 +29,14 @@
 #include <kio/job.h>
 #include <kio/scheduler.h>
 
-K_PLUGIN_FACTORY(UAChangerPluginFactory, registerPlugin<UAChangerPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(UAChangerPlugin, "uachangerplugin.json")
 
 #define UA_PTOS(x) (*it)->property(x).toString()
 #define QFL1(x) QLatin1String(x)
 
 UAChangerPlugin::UAChangerPlugin(QObject *parent,
                                  const QVariantList &)
-    : KParts::Plugin(parent),
+    : KonqParts::Plugin(parent),
       m_bSettingsLoaded(false), m_part(nullptr), m_config(nullptr)
 {
     m_pUAMenu = new KActionMenu(QIcon::fromTheme("preferences-web-browser-identification"),
