@@ -83,7 +83,7 @@
 #include "utils.h"
 #include <kio_version.h>
 
-static QWebEngineScript detectRefreshScript() {
+QWebEngineScript WebEnginePart::detectRefreshScript() {
     static QWebEngineScript s_detectRefreshScript;
     if (s_detectRefreshScript.isNull()) {
         QFile jsfile(":/hasrefresh.js");
@@ -195,25 +195,31 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     connect(m_webView, &QWebEngineView::loadFinished,
             this, &WebEnginePart::slotLoadFinished);
 
-    page()->scripts().insert(detectRefreshScript());
-    // Connect the signals from the page...
-    connectWebEnginePageSignals(page());
-
     // Init the QAction we are going to use...
     initActions();
 
     // Load plugins once we are fully ready
-    loadPlugins();
-    setWallet(page()->wallet());
-    if (m_wallet) {
-        page()->scripts().insert(WebEngineWallet::formDetectorFunctionsScript());
-    }
+    setWallet(new WebEngineWallet(this, parentWidget ? parentWidget->window()->winId() : 0));
+
+    setPage(page());
 }
 
 WebEnginePart::~WebEnginePart()
 {
 }
 
+void WebEnginePart::setPage(WebEnginePage* newPage)
+{
+    WebEnginePage *oldPage = page();
+    if (oldPage && oldPage != newPage) {
+        m_webView->setPage(newPage);
+        newPage->setParent(m_webView);
+    }
+    newPage->setPart(this);
+    // Connect the signals from the page...
+    connectWebEnginePageSignals(newPage);
+}
+
 WebEnginePage* WebEnginePart::page()
 {
     if (m_webView)
@@ -390,6 +396,11 @@ void WebEnginePart::setWallet(WebEngineWallet* wallet)
     }
 }
 
+WebEngineWallet* WebEnginePart::wallet() const
+{
+    return m_wallet;
+}
+
 void WebEnginePart::attemptInstallKIOSchemeHandler(const QUrl& url)
 {
      if (KProtocolManager::defaultMimetype(url) == "text/html") { // man:, info:, etc.
@@ -403,17 +414,13 @@ void WebEnginePart::attemptInstallKIOSchemeHandler(const QUrl& url)
 
 }
 
-bool WebEnginePart::openUrl(const QUrl &_u)
+bool WebEnginePart::openUrl(const QUrl& _u)
 {
-    QUrl u (_u);
-
-    if (property("urlRequestedByApp").toString() == u.url()) {
-        page()->markUrlAsRequestedByApp(u);
+    if (_u.isEmpty()) {
+        return false;
     }
 
-    // Ignore empty requests...
-    if (u.isEmpty())
-        return false;
+    QUrl u(_u);
 
     // If the URL given is a supported local protocol, e.g. "bookmark" but lacks
     // a path component, we set the path to "/" here so that the security context
@@ -453,6 +460,7 @@ bool WebEnginePart::openUrl(const QUrl &_u)
     return true;
 }
 
+
 bool WebEnginePart::closeUrl()
 {
     m_webView->triggerPageAction(QWebEnginePage::Stop);
@@ -471,6 +479,12 @@ bool WebEnginePart::isModified() const
     return false;
 }
 
+// QWebEngineProfile * WebEnginePart::profile() const
+// {
+//     return WebEnginePartControls::self()->profile();
+// }
+//
+
 void WebEnginePart::guiActivateEvent(KParts::GUIActivateEvent *event)
 {
     if (event && event->activated() && m_webView) {
@@ -859,11 +873,11 @@ void WebEnginePart::togglePasswordStorableState(bool on)
 
 void WebEnginePart::slotRemoveCachedPasswords()
 {
-    if (!page() || !page()->wallet()) {
+    if (!m_wallet) {
         return;
     }
 
-    page()->wallet()->removeFormData(page());
+    m_wallet->removeFormData(page());
     updateWalletData(WalletData::HasCachedData, false);
 }
 
